#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_BITOFSIGN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_BITOFSIGN_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/bitofsign.hpp>

#endif
